# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class TimezoneDetail(Model):
    """TimezoneDetail.

    :param id:
    :type id: str
    :param name:
    :type name: str
    """

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(TimezoneDetail, self).__init__(**kwargs)
        self.id = kwargs.get('id', None)
        self.name = kwargs.get('name', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class DependencyValidationIssue(Model):
    """DependencyValidationIssue.

    :param type: Possible values include: 'mapInvalid', 'matchRuleInvalid',
     'mergePolicyInvalid', 'relationshipInvalid', 'measureDefinitionInvalid',
     'segmentDefinitionInvalid', 'unifiedActivitiyMappingInvalid', 'generic'
    :type type: str or ~dynamics.customerinsights.api.models.enum
    :param severity: Possible values include: 'error', 'warning'
    :type severity: str or ~dynamics.customerinsights.api.models.enum
    :param id:
    :type id: str
    :param description:
    :type description: str
    """

    _attribute_map = {
        'type': {'key': 'type', 'type': 'str'},
        'severity': {'key': 'severity', 'type': 'str'},
        'id': {'key': 'id', 'type': 'str'},
        'description': {'key': 'description', 'type': 'str'},
    }

    def __init__(self, *, type=None, severity=None, id: str=None, description: str=None, **kwargs) -> None:
        super(DependencyValidationIssue, self).__init__(**kwargs)
        self.type = type
        self.severity = severity
        self.id = id
        self.description = description



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from .instance_creation_request import InstanceCreationRequest


class InstancesV2PostRequest(InstanceCreationRequest):
    """The instance creation request.

    :param instance_metadata:
    :type instance_metadata:
     ~dynamics.customerinsights.api.models.InstanceMetadata
    :param byosa_resource_metadata:
    :type byosa_resource_metadata:
     ~dynamics.customerinsights.api.models.ResourceMetadata
    :param cds_resource_metadata:
    :type cds_resource_metadata:
     ~dynamics.customerinsights.api.models.ResourceMetadata
    :param bap_provisioning_type: Possible values include: 'skip', 'create',
     'attach'
    :type bap_provisioning_type: str or
     ~dynamics.customerinsights.api.models.enum
    """

    _attribute_map = {
        'instance_metadata': {'key': 'instanceMetadata', 'type': 'InstanceMetadata'},
        'byosa_resource_metadata': {'key': 'byosaResourceMetadata', 'type': 'ResourceMetadata'},
        'cds_resource_metadata': {'key': 'cdsResourceMetadata', 'type': 'ResourceMetadata'},
        'bap_provisioning_type': {'key': 'bapProvisioningType', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(InstancesV2PostRequest, self).__init__(**kwargs)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from .role_assignment_py3 import RoleAssignment


class InstancesInstanceIdRbacPrincipalsPrincipalIdAssignmentPutRequest1(RoleAssignment):
    """Represents a role assignment Metadata.

    :param principal_id: Gets the Id of the principal.
    :type principal_id: str
    :param principal_type: Possible values include: 'user', 'group', 'app'
    :type principal_type: str or ~dynamics.customerinsights.api.models.enum
    :param roles: Gets the roles the principal belongs to.
    :type roles: list[str]
    :param instance_id: Customer Insights instance id associated with this
     object.
    :type instance_id: str
    """

    _attribute_map = {
        'principal_id': {'key': 'principalId', 'type': 'str'},
        'principal_type': {'key': 'principalType', 'type': 'str'},
        'roles': {'key': 'roles', 'type': '[str]'},
        'instance_id': {'key': 'instanceId', 'type': 'str'},
    }

    def __init__(self, *, principal_id: str=None, principal_type=None, roles=None, instance_id: str=None, **kwargs) -> None:
        super(InstancesInstanceIdRbacPrincipalsPrincipalIdAssignmentPutRequest1, self).__init__(principal_id=principal_id, principal_type=principal_type, roles=roles, instance_id=instance_id, **kwargs)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from .instance_search_configuration import InstanceSearchConfiguration


class InstancesInstanceIdManageSearchPutRequest(InstanceSearchConfiguration):
    """Represents search configuration of an instance.

    :param entity_config: Gets search configurations for entities
    :type entity_config:
     list[~dynamics.customerinsights.api.models.EntitySearchConfiguration]
    :param is_system_generated: Gets a value indicating whether the
     configuration was system generated
    :type is_system_generated: bool
    :param version: Version number of this object.
    :type version: long
    :param updated_by: UPN of the user who last updated this record.
    :type updated_by: str
    :param updated_utc: Time this object was last updated.
    :type updated_utc: datetime
    :param created_by: Email address of the user who created this record.
    :type created_by: str
    :param created_utc: Time this object was initially created.
    :type created_utc: datetime
    :param instance_id: Customer Insights instance id associated with this
     object.
    :type instance_id: str
    """

    _attribute_map = {
        'entity_config': {'key': 'entityConfig', 'type': '[EntitySearchConfiguration]'},
        'is_system_generated': {'key': 'isSystemGenerated', 'type': 'bool'},
        'version': {'key': 'version', 'type': 'long'},
        'updated_by': {'key': 'updatedBy', 'type': 'str'},
        'updated_utc': {'key': 'updatedUtc', 'type': 'iso-8601'},
        'created_by': {'key': 'createdBy', 'type': 'str'},
        'created_utc': {'key': 'createdUtc', 'type': 'iso-8601'},
        'instance_id': {'key': 'instanceId', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(InstancesInstanceIdManageSearchPutRequest, self).__init__(**kwargs)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from .instance_creation_request_py3 import InstanceCreationRequest


class InstancesInstanceIdV2PatchRequest1(InstanceCreationRequest):
    """InstancesInstanceIdV2PatchRequest1.

    :param instance_metadata:
    :type instance_metadata:
     ~dynamics.customerinsights.api.models.InstanceMetadata
    :param byosa_resource_metadata:
    :type byosa_resource_metadata:
     ~dynamics.customerinsights.api.models.ResourceMetadata
    :param cds_resource_metadata:
    :type cds_resource_metadata:
     ~dynamics.customerinsights.api.models.ResourceMetadata
    :param bap_provisioning_type: Possible values include: 'skip', 'create',
     'attach'
    :type bap_provisioning_type: str or
     ~dynamics.customerinsights.api.models.enum
    """

    _attribute_map = {
        'instance_metadata': {'key': 'instanceMetadata', 'type': 'InstanceMetadata'},
        'byosa_resource_metadata': {'key': 'byosaResourceMetadata', 'type': 'ResourceMetadata'},
        'cds_resource_metadata': {'key': 'cdsResourceMetadata', 'type': 'ResourceMetadata'},
        'bap_provisioning_type': {'key': 'bapProvisioningType', 'type': 'str'},
    }

    def __init__(self, *, instance_metadata=None, byosa_resource_metadata=None, cds_resource_metadata=None, bap_provisioning_type=None, **kwargs) -> None:
        super(InstancesInstanceIdV2PatchRequest1, self).__init__(instance_metadata=instance_metadata, byosa_resource_metadata=byosa_resource_metadata, cds_resource_metadata=cds_resource_metadata, bap_provisioning_type=bap_provisioning_type, **kwargs)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class InstanceInfo(Model):
    """Represents an instance.

    :param instance_id: Gets the unique ID for this instance.
    :type instance_id: str
    :param name: Gets the instance name. (not persisted in store)
    :type name: str
    :param instance_type: Possible values include: 'trial', 'sandbox',
     'production'
    :type instance_type: str or ~dynamics.customerinsights.api.models.enum
    :param expiry_time_utc: Gets the time the instance is set to expire. (not
     persisted in store)
    :type expiry_time_utc: datetime
    """

    _attribute_map = {
        'instance_id': {'key': 'instanceId', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'instance_type': {'key': 'instanceType', 'type': 'str'},
        'expiry_time_utc': {'key': 'expiryTimeUtc', 'type': 'iso-8601'},
    }

    def __init__(self, **kwargs):
        super(InstanceInfo, self).__init__(**kwargs)
        self.instance_id = kwargs.get('instance_id', None)
        self.name = kwargs.get('name', None)
        self.instance_type = kwargs.get('instance_type', None)
        self.expiry_time_utc = kwargs.get('expiry_time_utc', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class DeletionResponse(Model):
    """DeletionResponse.

    :param is_deleted:
    :type is_deleted: bool
    :param issues:
    :type issues:
     list[~dynamics.customerinsights.api.models.DependencyValidationIssue]
    """

    _attribute_map = {
        'is_deleted': {'key': 'isDeleted', 'type': 'bool'},
        'issues': {'key': 'issues', 'type': '[DependencyValidationIssue]'},
    }

    def __init__(self, *, is_deleted: bool=None, issues=None, **kwargs) -> None:
        super(DeletionResponse, self).__init__(**kwargs)
        self.is_deleted = is_deleted
        self.issues = issues



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ResourceMetadata(Model):
    """Represents a Resource metadata.

    :param kind: Possible values include: 'bearerAuthenticationConnection',
     'sshKeyAuthenticationConnection', 'apiKeyAuthenticationConnection',
     'basicAuthenticationConnection', 'adlsGen2', 'd365Sales', 'd365Marketing',
     'attachCds', 'ftp', 'facebookAds', 'http', 'mailchimp', 'googleAds',
     'marketo'
    :type kind: str or ~dynamics.customerinsights.api.models.enum
    :param resource_id: Gets the Id of the resource.
    :type resource_id: str
    :param operation_id: Gets the Id of the operation being performed on the
     resource.
    :type operation_id: str
    :param resource_type: Possible values include: 'adlsGen2', 'd365Sales',
     'cds', 'ftp', 'bearerAuthenticationConnection',
     'sshKeyAuthenticationConnection', 'apiKeyAuthenticationConnection',
     'basicAuthenticationConnection', 'facebookAds', 'http', 'mailchimp',
     'googleAds', 'marketo'
    :type resource_type: str or ~dynamics.customerinsights.api.models.enum
    :param name: Gets the Name of the resource.
    :type name: str
    :param description: Gets the Description of the resource.
    :type description: str
    :param version: Version number of this object.
    :type version: long
    :param updated_by: UPN of the user who last updated this record.
    :type updated_by: str
    :param updated_utc: Time this object was last updated.
    :type updated_utc: datetime
    :param created_by: Email address of the user who created this record.
    :type created_by: str
    :param created_utc: Time this object was initially created.
    :type created_utc: datetime
    :param instance_id: Customer Insights instance id associated with this
     object.
    :type instance_id: str
    """

    _attribute_map = {
        'kind': {'key': 'kind', 'type': 'str'},
        'resource_id': {'key': 'resourceId', 'type': 'str'},
        'operation_id': {'key': 'operationId', 'type': 'str'},
        'resource_type': {'key': 'resourceType', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'description': {'key': 'description', 'type': 'str'},
        'version': {'key': 'version', 'type': 'long'},
        'updated_by': {'key': 'updatedBy', 'type': 'str'},
        'updated_utc': {'key': 'updatedUtc', 'type': 'iso-8601'},
        'created_by': {'key': 'createdBy', 'type': 'str'},
        'created_utc': {'key': 'createdUtc', 'type': 'iso-8601'},
        'instance_id': {'key': 'instanceId', 'type': 'str'},
    }

    def __init__(self, *, kind=None, resource_id: str=None, operation_id: str=None, resource_type=None, name: str=None, description: str=None, version: int=None, updated_by: str=None, updated_utc=None, created_by: str=None, created_utc=None, instance_id: str=None, **kwargs) -> None:
        super(ResourceMetadata, self).__init__(**kwargs)
        self.kind = kind
        self.resource_id = resource_id
        self.operation_id = operation_id
        self.resource_type = resource_type
        self.name = name
        self.description = description
        self.version = version
        self.updated_by = updated_by
        self.updated_utc = updated_utc
        self.created_by = created_by
        self.created_utc = created_utc
        self.instance_id = instance_id
